HPGL web resources — Chiplotle v0.1 documentation

### Navigation

- index
- modules |
- previous |
- Chiplotle »
- Chiplotle v0.1 documentation »

# HPGL web resources

## HPGL references

- http://local.wasp.uwa.edu.au/~pbourke/dataformats/hpgl/

## Tools

- pstoedit: a handy tool useful to convert post script files to HPGL.
- potrace: transform your bitmaps into vector graphics.

### Navigation

- index
- modules |
- previous |
- Chiplotle »
- Chiplotle v0.1 documentation »